==> mct_nightly-1.3.0.2052022.post508-py3-none-any.whl: model_compression_toolkit/hardware_models/pytorch_hardware_model/pytorch_qnnpack.py <==
# Copyright 2022 Sony Semiconductors Israel, Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================


import torch
from torch.nn import Conv2d, Linear, BatchNorm2d, ConvTranspose2d, Hardtanh, ReLU, ReLU6
from torch.nn.functional import relu, relu6, hardtanh

from model_compression_toolkit.common.target_platform.hardware2framework import \
    FrameworkHardwareModel, LayerFilterParams
from model_compression_toolkit.common.target_platform.hardware2framework import \
    OperationsSetToLayers
from model_compression_toolkit.hardware_models.qnnpack import get_qnnpack_model


def get_qnnpack_pytorch():
    qnnpackhm = get_qnnpack_model()
    qnnpack_pytorch = FrameworkHardwareModel(qnnpackhm,
                                             name='qnnpack_pytorch')

    with qnnpack_pytorch:
        OperationsSetToLayers("Conv", [Conv2d,
                                       torch.nn.functional.conv2d,
                                       ConvTranspose2d,
                                       torch.nn.functional.conv_transpose2d])

        OperationsSetToLayers("Linear", [Linear])

        OperationsSetToLayers("BatchNorm", [BatchNorm2d])

        OperationsSetToLayers("Relu", [torch.relu,
                                       ReLU,
                                       ReLU6,
                                       relu,
                                       relu6,
                                       LayerFilterParams(Hardtanh, min_val=0),
                                       LayerFilterParams(hardtanh, min_val=0)])

    return qnnpack_pytorch

==> mct_nightly-1.3.0.19042022.post353-py3-none-any.whl: model_compression_toolkit/hardware_models/pytorch_hardware_model/pytorch_qnnpack.py <==
# Copyright 2022 Sony Semiconductors Israel, Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================


import torch
from torch.nn import Conv2d, Linear, BatchNorm2d, ConvTranspose2d, Hardtanh, ReLU, ReLU6
from torch.nn.functional import relu, relu6, hardtanh

from model_compression_toolkit.common.hardware_representation.hardware2framework import \
    FrameworkHardwareModel, LayerFilterParams
from model_compression_toolkit.common.hardware_representation.hardware2framework import \
    OperationsSetToLayers
from model_compression_toolkit.hardware_models.qnnpack import get_qnnpack_model


def get_qnnpack_pytorch():
    qnnpackhm = get_qnnpack_model()
    qnnpack_pytorch = FrameworkHardwareModel(qnnpackhm,
                                             name='qnnpack_pytorch')

    with qnnpack_pytorch:
        OperationsSetToLayers("Conv", [Conv2d,
                                       torch.nn.functional.conv2d,
                                       ConvTranspose2d,
                                       torch.nn.functional.conv_transpose2d])

        OperationsSetToLayers("Linear", [Linear])

        OperationsSetToLayers("BatchNorm", [BatchNorm2d])

        OperationsSetToLayers("Relu", [torch.relu,
                                       ReLU,
                                       ReLU6,
                                       relu,
                                       relu6,
                                       LayerFilterParams(Hardtanh, min_val=0),
                                       LayerFilterParams(hardtanh, min_val=0)])

    return qnnpack_pytorch
